@@ -37,6 +37,7 @@ class vtkInformationDoubleVectorKey;
 class vtkInformationIdTypeKey;
 class vtkInformationIntegerKey;
 class vtkInformationIntegerVectorKey;
+class vtkInformationIterator;
 class vtkInformationObjectBaseKey;
 class vtkInformationStringKey;
 class vtkInformationStringKey;
@@ -114,7 +115,7 @@ public:
    */
   static int SetWholeExtent(vtkInformation *, int extent[6]);
   static void GetWholeExtent(vtkInformation *, int extent[6]);
-  static int* GetWholeExtent(vtkInformation *);
+  static int* GetWholeExtent(vtkInformation *) VTK_SIZEHINT(6);
   //@}
 
   //@{
@@ -122,7 +123,7 @@ public:
    * This request flag indicates whether the requester can handle more
    * data than requested for the given port.  Right now it is used in
    * vtkImageData.  Image filters can return more data than requested.
-   * The the consumer cannot handle this (i.e. DataSetToDataSetFitler)
+   * The consumer cannot handle this (i.e. DataSetToDataSetfilter)
    * the image will crop itself.  This functionality used to be in
    * ImageToStructuredPoints.
    */
@@ -318,6 +319,9 @@ protected:
   int ContinueExecuting;
 
   vtkInformation *UpdateExtentRequest;
+  vtkInformation *UpdateTimeRequest;
+  vtkInformation *TimeDependentInformationRequest;
+  vtkInformationIterator *InformationIterator;
 
   // did the most recent PUE do anything ?
   int LastPropogateUpdateExtentShortCircuited;
